/*jshint node:true*/
var path = require('path'),
	NamedBase = require('../NamedBase');

module.exports = NamedBase.extend({
	constructor: function () {
		NamedBase.apply(this, arguments);

		this.cssName = this._.dasherize(this.name);

		if (this.cssName.charAt(0) === '-') {
			this.cssName = this.cssName.slice(1);
		}
	},
	askFor: function () {
		var cb = this.async();

		var prompts = [{
			name: 'base',
			message: 'What does this widget inherit from?',
			'default': 'dijit/_WidgetBase'
		}, {
			type: 'confirm',
			name: 'templated',
			message: 'Is it templated?',
			'default': true
		}, {
			type: 'confirm',
			name: 'widgetsInTemplate',
			message: 'Will there be widgets in the template?',
			when: function (answers) {
				return answers.templated;
			},
			'default': true
		}, {
			type: 'input',
			name: 'mixins',
			message: 'Other mixins to include (comma separated)',
			filter: function (value) {
				value = value.trim();
				if (!value) {
					return [];
				}
				return value.split(',').map(function (mixin) { return mixin.trim(); });
			}
		}, {
			type: 'confirm',
			name: 'css',
			message: 'Include a stylesheet?',
			'default': true
		}, {
			type: 'confirm',
			name: 'unitTest',
			message: 'Include a unit test?',
			'default': true
		}, {
			type: 'confirm',
			name: 'functionalTest',
			message: 'Include a functional test?',
			'default': true
		}];

		this.prompt(prompts, function (props) {
			this.base = props.base;
			this.baseName = path.basename(this.base);
			this.templated = props.templated;
			this.widgetsInTemplate = props.widgetsInTemplate;
			this.css = props.css;
			this.unitTest = props.unitTest;
			this.functionalTest = props.functionalTest;

			var mixins = [];

			if (this.templated) {
				mixins.push('dijit/_TemplatedMixin');

				if (this.widgetsInTemplate) {
					mixins.push('dijit/_WidgetsInTemplateMixin');
				}
			}

			this.mixins = mixins = mixins.concat(props.mixins);

			this.mixinPackages = mixins.length ? this.mixins.join('\',\n\t\'') : '';
			this.mixinNames = mixins.length ? mixins.map(function (mixin) { return path.basename(mixin); }).join(', ') : '';

			cb();
		}.bind(this));
	},
	files: function () {
		var appPath = path.join('src', this.appname),
			widgetPath = path.join(appPath, this.subdir);

		this.template('_Widget.js', path.join(widgetPath, this.name + '.js'));
		if (this.templated) {
			this.copy('Widget.html', path.join(widgetPath, 'templates', this.name + '.html'));
		}

		if (this.css) {
			var extension = this.config.get('packages').stylus ? '.styl' : '.css';
			this.template('Widget' + extension, path.join(appPath, 'resources', this.subdir, this.name + extension));
		}
	}
});
